
print(111);
from rabbitmq_utils import rabbitmq_helper;

if __name__ =="__main__":
    print(111);
    mq = rabbitmq_helper('admin', 'admin2022','106.14.112.246');
    @mq.receive_message('python-test')
    def recived(data):
        print(data);
        return True;
    mq.listen();
# if __name__ =="__main__":
#     rabbitmq_utils.rabbitmq();
#     # break;


import pika
import json

credentials = pika.PlainCredentials('admin', 'admin2022')  # mq用户名和密码
# 虚拟队列需要指定参数 virtual_host，如果是默认的可以不填。
connection = pika.BlockingConnection(
    pika.ConnectionParameters(host='106.14.112.246', port=5672, virtual_host='/', credentials=credentials))
channel = connection.channel()
# 声明消息队列，消息将在这个队列传递，如不存在，则创建
result = channel.queue_declare(queue='python-test')

for i in range(10):
    message = json.dumps({'OrderId': "1000%s" % i})
    # 向队列插入数值 routing_key是队列名
    channel.basic_publish(exchange='', routing_key='python-test', body=message)
    print(message)
connection.close()



import json
import rabbitmq_utils;

mq = rabbitmq_utils.rabbitmq_helper('admin', 'admin2022','106.14.112.246');

for i in range(10):
    message = json.dumps({'OrderId':"1000%s"%i})
    mq.send_message(message,'python-test')


from cmath import log
import functools
from threading import Thread
import threading
from time import sleep
import pika
import retry
import logging
import uuid;
logging.basicConfig(level = logging.INFO,format = '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)

class rabbitmq_helper():
    message_dict:dict
    thread_stop_flag:dict;
    def __init__(self,user,pwd,host) -> None:
        self.user = user;
        self.pwd  = pwd;
        self.host = host;
        self.message_dict = {};
        self.thread_stop_flag = {};

    def send_message(self,body,quenuName):
        credentials = pika.PlainCredentials(self.user, self.pwd)  # mq用户名和密码
        connection = pika.BlockingConnection(pika.ConnectionParameters(host = self.host,port = 5672,virtual_host = '/',credentials = credentials,heartbeat=10))
        self.channel = connection.channel()
        self.channel.queue_declare(queue = quenuName,durable = True)
        self.channel.basic_publish(exchange = '',routing_key = quenuName,body = body,properties=pika.BasicProperties(delivery_mode = 2))
        connection.close()

    def ack_message(self,channel, delivery_tag):
        # print(f'ack_message thread id: {threading.get_ident()}')
        logger.info(f'ack_message thread id: {threading.get_ident()}')
        if channel.is_open:
            channel.basic_ack(delivery_tag)
        else:
            # Channel is already closed, so we can't ACK this message;
            # log and/or do something that makes sense for your app in this case.
            pass

    def receive_message(self,name):
        def wrap(func):
            self.message_dict[name] = func;
        return wrap;
    
    def do_work(self,channel, delivery_tag, body,r_k):
        flag = self.message_dict[r_k](body.decode(encoding="utf-8"));
        if flag:
            try:
                cb = functools.partial(self.ack_message,channel, delivery_tag)
                channel.connection.add_callback_threadsafe(cb)
            except Exception as e:
                logger.error(e);

    def callback(self,ch, method, properties, body):
        flag = False;
        try:
            delivery_tag = method.delivery_tag
            r_k = method.routing_key;
            t = threading.Thread(target=self.do_work, args=(ch, delivery_tag, body,r_k))
            t.start()
        except Exception as e:
            print(e);

    def heart_thread(self,conn,uuid):
        while True:
            try:
                if  self.thread_stop_flag[uuid]:
                    break;
                else:
                    conn.process_data_events();
            except Exception:
                pass;
            sleep(5);


    @retry.retry((pika.exceptions.AMQPConnectionError), delay=5, jitter=(1, 3))
    def listen(self):
        if self.__dict__.__contains__("connection"):
           if self.connection.is_open:
                self.connection.close();
        logging.info("开始启动")
        credentials = pika.PlainCredentials(self.user, self.pwd)  # mq用户名和密码
        self.connection = pika.BlockingConnection(pika.ConnectionParameters(socket_timeout=10,host = self.host,port = 5672,virtual_host = '/',credentials = credentials,heartbeat=5))
        self.channel = self.connection.channel()
        self.channel.basic_qos(prefetch_count=1)
        self.connection.add_callback_threadsafe
        for i in self.message_dict.keys():
                self.channel.basic_consume(i,self.callback);
        try:
            self.channel.start_consuming()
        except pika.exceptions.ConnectionClosedByBroker:
            pass


from th_txmessage.tx_ms_utils import TxYunMessageUtils
import traceback
import json
import time


class TxyunMessage:
    message_deal_process = {}
    message_deal_process_after = {}
    
    def message_deal(self, messageType):
        def wrap(func):
            self.message_deal_process[messageType] = func
            return func
        return wrap
    
    def message_deal_after(self,messageType):
        def wrap(func):
            self.message_deal_process_after[messageType] = func
            return func
        return wrap
    
    def error_deal(self):
        def wrap(func):
            self.m_error_deal = func
            return func
        return wrap
    
    
    
    def __init__(self, qname, secretId, secretKey) -> None:
        self.qname = qname
        self.secretId = secretId
        self.secretKey = secretKey
        txyunUtils = TxYunMessageUtils(self.secretId, self.secretKey)
        self.txyunUtils = txyunUtils;

    def listent2(self):
        while True:
            try:
                myQueue = self.txyunUtils.getQueue(self.qname)
                recv_msg = myQueue.receive_message(3)
                messageBody = json.loads(recv_msg.msgBody)
                if "lx" not in messageBody.keys() or "data" not in messageBody.keys():
                        myQueue.delete_message(recv_msg.receiptHandle)
                else:
                    self.run(
                            message_type=messageBody["lx"], message_body=messageBody["data"])
                    if messageBody["lx"] in self.message_deal_process_after.keys():
                                self.message_deal_process_after[messageBody["lx"]](myQueue,recv_msg)
            except Exception as e:
                    self.m_error_deal(e)
    
    def listent(self):
        while True:
            try:
                myQueue = self.txyunUtils.getQueue(self.qname)
                recv_msg = myQueue.receive_message(3)
            except Exception as e:
                # time.sleep(30)
                pass
            else:
                try:
                    messageBody = json.loads(recv_msg.msgBody)
                    if "lx" not in messageBody.keys() or "data" not in messageBody.keys():
                        myQueue.delete_message(recv_msg.receiptHandle)
                    else:
                        flag = self.run(
                            message_type=messageBody["lx"], message_body=messageBody["data"])
                        if flag == True:
                            myQueue.delete_message(recv_msg.receiptHandle)
                            # t = 0
                            # while True:
                            #     try:
                            #         myQueue.delete_message(recv_msg.receiptHandle)
                            #     except:
                            #         t += 1
                            #         print(f'消息删除失败==={t}')
                            #         if t > 100:
                            #             break
                            #         time.sleep(0.5)
                            #         continue
                except Exception as e:
                    time.sleep(2)
                    traceback.print_exc()

    def run(self, message_type, message_body):
        if message_type in self.message_deal_process.keys():
            return self.message_deal_process[message_type](message_body)



from setuptools import setup, find_packages

setup(name='th_txmessage',  # 打包后的包文件名
      version='4.1.4',  # 版本号
      description='听海内部爬虫核心类库',  # 说明
      long_description="听海爬虫组一些核心代码集合",  # 详细说明
      license="MIT Licence",  # 许可
      url='',
      author='wzr',
      author_email='510540795@qq.com',
      packages=find_packages(),  # 这个参数是导入目录下的所有__init__.py包
      include_package_data=True,
      platforms="any",
      install_requires=["apscheduler", "qcloud-cmq-sdk-py3", "requests", "retry"],  # 引用到的第三方库
      # py_modules=['pip-test.DoRequest', 'pip-test.GetParams', 'pip-test.ServiceRequest',
      #             'pip-test.ts.constants', 'pip-test.ac.Agent2C',
      #             'pip-test.ts.ttypes', 'pip-test.ac.constants',
      #             'pip-test.__init__'],  # 你要打包的文件，这里用下面这个参数代替
      # packages=[''] # 这个参数是导入目录下的所有__init__.py包
      )



import pika

credentials = pika.PlainCredentials('admin', 'admin2022')  # mq用户名和密码
# 虚拟队列需要指定参数 virtual_host，如果是默认的可以不填。
connection = pika.BlockingConnection(pika.ConnectionParameters(host = '106.14.112.246',port = 5672,virtual_host = '/',credentials = credentials))
channel = connection.channel()
# 申明消息队列，消息在这个队列传递，如果不存在，则创建队列
channel.queue_declare(queue = 'python-test', durable = False)
# 定义一个回调函数来处理消息队列中的消息，这里是打印出来
def callback(ch, method, properties, body):
    ch.basic_ack(delivery_tag = method.delivery_tag)
    # print(body.decode())
# 告诉rabbitmq，用callback来接收消息
channel.basic_consume('python-test',callback)
# 开始接收信息，并进入阻塞状态，队列里有信息才会调用callback进行处理
channel.start_consuming()